==> haskell-th-lift-instances-0.1.20-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-lift-instances
version:              0.1.20
visibility:           public
id:                   th-lift-instances-0.1.20-L9lFeMq1oic3NYmDk9nmmY
key:                  th-lift-instances-0.1.20-L9lFeMq1oic3NYmDk9nmmY
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2020 Benno Fünfstück
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Benno Fünfstück
stability:            experimental
homepage:             http://github.com/bennofs/th-lift-instances/
synopsis:             Lift instances for template-haskell for common data types.
description:
    Most data types in the haskell platform do not have Lift instances.
    This package provides orphan instances for containers, text, bytestring and vector.
    It also provides compat instances for older versions of @template-haskell@

    Note that <https://hackage.haskell.org/package/th-lift th-lift> package provides
    Template Haskell based derivation of @Lift@ instances (when you cannot use @DeriveLift@ extension),
    and <https://hackage.haskell.org/package/th-orphans th-orphans> package provides instances for TH datatypes.

category:             Template Haskell
abi:                  d6171e9cf986e0a440e6806dafc26bde
exposed:              True
exposed-modules:      Instances.TH.Lift
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-lift-instances-0.1.20
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-lift-instances-0.1.20
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-lift-instances-0.1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-lift-instances
hs-libraries:         HSth-lift-instances-0.1.20-L9lFeMq1oic3NYmDk9nmmY
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    template-haskell-2.19.0.0 text-2.0.2
    th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx transformers-0.5.6.2
    vector-0.13.2.0-3KdUWUHYfVjDmpelwHDbn6

haddock-interfaces:
    /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock

haddock-html:         /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-instances-0.1.20-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-lift-instances
version:              0.1.20
visibility:           public
id:                   th-lift-instances-0.1.20-EZfzjIJ9NWAFsisDHhtBMC
key:                  th-lift-instances-0.1.20-EZfzjIJ9NWAFsisDHhtBMC
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2020 Benno Fünfstück
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Benno Fünfstück
stability:            experimental
homepage:             http://github.com/bennofs/th-lift-instances/
synopsis:             Lift instances for template-haskell for common data types.
description:
    Most data types in the haskell platform do not have Lift instances.
    This package provides orphan instances for containers, text, bytestring and vector.
    It also provides compat instances for older versions of @template-haskell@

    Note that <https://hackage.haskell.org/package/th-lift th-lift> package provides
    Template Haskell based derivation of @Lift@ instances (when you cannot use @DeriveLift@ extension),
    and <https://hackage.haskell.org/package/th-orphans th-orphans> package provides instances for TH datatypes.

category:             Template Haskell
abi:                  5a22d5ee5d8cccf4e52fa19d89a53706
exposed:              True
exposed-modules:      Instances.TH.Lift
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-lift-instances-0.1.20
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-lift-instances-0.1.20
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-lift-instances-0.1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-lift-instances
hs-libraries:         HSth-lift-instances-0.1.20-EZfzjIJ9NWAFsisDHhtBMC
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    template-haskell-2.19.0.0 text-2.0.2
    th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx transformers-0.5.6.2
    vector-0.13.2.0-ZKpjTfyjPa7BNElf7Ue7Z

haddock-interfaces:
    /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock

haddock-html:         /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
